@@ -29,7 +29,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 namespace Gwenview
 {
-
 namespace Sorting
 {
 /**
@@ -40,7 +39,7 @@ enum Enum {
     Size,
     Date,
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
-    Rating
+    Rating,
 #endif
 };
 
